@@ -14,10 +14,12 @@ specific language governing permissions and limitations under the License.
 import logging
 import traceback
 
+from blueapps.core.exceptions.base import MethodError
 from django.conf import settings
 from django.contrib.auth.backends import ModelBackend
 from django.db import IntegrityError
 
+from blueapps import metrics
 from blueapps.account import get_user_model
 from blueapps.account.conf import ConfFixture
 from blueapps.account.utils.http import send
@@ -28,10 +30,12 @@ logger = logging.getLogger("component")
 
 ROLE_TYPE_ADMIN = "1"
 
+TOKEN_TYPE = "bk_token"
+
 
 class TokenBackend(ModelBackend):
     def authenticate(self, request=None, bk_token=None):
-        logger.debug(u"Enter in TokenBackend")
+        logger.debug("Enter in TokenBackend")
         # 判断是否传入验证所需的bk_token,没传入则返回None
         if not bk_token:
             return None
@@ -69,13 +73,11 @@ class TokenBackend(ModelBackend):
 
         except IntegrityError:
             logger.exception(traceback.format_exc())
-            logger.exception(
-                u"get_or_create UserModel fail or update_or_create UserProperty"
-            )
+            logger.exception("get_or_create UserModel fail or update_or_create UserProperty")
             return None
         except Exception:  # pylint: disable=broad-except
             logger.exception(traceback.format_exc())
-            logger.exception(u"Auto create & update UserModel fail")
+            logger.exception("Auto create & update UserModel fail")
             return None
 
     @staticmethod
@@ -108,7 +110,7 @@ class TokenBackend(ModelBackend):
         try:
             response = client.bk_login.get_user(api_params)
         except Exception as err:  # pylint: disable=broad-except
-            logger.exception(u"Abnormal error in get_user_info...:%s" % err)
+            logger.exception("Abnormal error in get_user_info...:%s" % err)
             return False, {}
 
         if response.get("result") is True:
@@ -135,14 +137,10 @@ class TokenBackend(ModelBackend):
         else:
             error_msg = response.get("message", "")
             error_data = response.get("data", "")
-            logger.error(
-                u"Failed to Get User Info: error=%(err)s, ret=%(ret)s"
-                % {u"err": error_msg, u"ret": error_data}
-            )
+            logger.error("Failed to Get User Info: error=%(err)s, ret=%(ret)s" % {"err": error_msg, "ret": error_data})
             return False, {}
 
-    @staticmethod
-    def verify_bk_token(bk_token, request=None):
+    def verify_bk_token(self, bk_token, request=None):
         """
         请求VERIFY_URL,认证bk_token是否正确
         @param bk_token: "_FrcQiMNevOD05f8AY0tCynWmubZbWz86HslzmOqnhk"
@@ -150,17 +148,59 @@ class TokenBackend(ModelBackend):
         @return: False,None True,username
         @rtype: bool,None/str
         """
+        try:
+            return self.verify_bk_token_through_esb(bk_token)
+        except (NotImplementedError, MethodError, AttributeError):
+            # 对应版本 esb 不支持 client.bk_login.is_login 接口的情况
+            return self.verify_bk_token_through_verify_url(bk_token, request)
+
+    @staticmethod
+    def verify_bk_token_through_esb(bk_token):
         api_params = {"bk_token": bk_token}
 
         try:
-            response = send(
-                resolve_login_url(ConfFixture.VERIFY_URL, request, "http"),
-                "GET",
-                api_params,
-                verify=False,
-            )
+            with metrics.observe(
+                metrics.BLUEAPPS_USER_TOKEN_VERIFY_DURATION, hostname=metrics.HOSTNAME, token_type=TOKEN_TYPE,
+            ):
+                response = client.bk_login.is_login(api_params)
+        except (NotImplementedError, MethodError, AttributeError):
+            raise
         except Exception:  # pylint: disable=broad-except
-            logger.exception(u"Abnormal error in verify_bk_token...")
+            metrics.BLUEAPPS_USER_TOKEN_VERIFY_FAILED_TOTAL.labels(
+                hostname=metrics.HOSTNAME, token_type=TOKEN_TYPE, err="unknow_execption_raise",
+            ).inc()
+            logger.exception("Abnormal error in verify_bk_token...")
+            return False, None
+
+        if response.get("result"):
+            data = response.get("data")
+            username = data.get("bk_username")
+            return True, username
+        else:
+            metrics.BLUEAPPS_USER_TOKEN_VERIFY_FAILED_TOTAL.labels(
+                hostname=metrics.HOSTNAME, token_type=TOKEN_TYPE, err="verify_fail"
+            ).inc()
+            error_msg = response.get("message", "")
+            error_data = response.get("data", "")
+            logger.error("Fail to verify bk_token, error={}, ret={}".format(error_msg, error_data))
+            return False, None
+
+    @staticmethod
+    def verify_bk_token_through_verify_url(bk_token, request=None):
+        api_params = {"bk_token": bk_token}
+
+        try:
+            with metrics.observe(
+                metrics.BLUEAPPS_USER_TOKEN_VERIFY_DURATION, hostname=metrics.HOSTNAME, token_type=TOKEN_TYPE
+            ):
+                response = send(
+                    resolve_login_url(ConfFixture.VERIFY_URL, request, "http"), "GET", api_params, verify=False,
+                )
+        except Exception:  # pylint: disable=broad-except
+            metrics.BLUEAPPS_USER_TOKEN_VERIFY_FAILED_TOTAL.labels(
+                hostname=metrics.HOSTNAME, token_type=TOKEN_TYPE, err="unknow_execption_raise"
+            ).inc()
+            logger.exception("Abnormal error in verify_bk_token...")
             return False, None
 
         if response.get("result"):
@@ -168,11 +208,10 @@ class TokenBackend(ModelBackend):
             username = data.get("username")
             return True, username
         else:
+            metrics.BLUEAPPS_USER_TOKEN_VERIFY_FAILED_TOTAL.labels(
+                hostname=metrics.HOSTNAME, token_type=TOKEN_TYPE, err="verify_fail"
+            ).inc()
             error_msg = response.get("message", "")
             error_data = response.get("data", "")
-            logger.error(
-                u"Fail to verify bk_token, error={}, ret={}".format(
-                    error_msg, error_data
-                )
-            )
+            logger.error("Fail to verify bk_token, error={}, ret={}".format(error_msg, error_data))
             return False, None
