@@ -10,6 +10,7 @@ Unless required by applicable law or agreed to in writing, software distributed
 an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 specific language governing permissions and limitations under the License.
 """
+from urllib.parse import urlencode
 
 from django.conf import settings
 from django.http import HttpResponseRedirect, JsonResponse
@@ -34,6 +35,9 @@ class ResponseHandler(object):
         self._conf = _confFixture
         self._settings = _settings
 
+    def build_403_response(self, msg):
+        return HttpResponseRedirect(f'{reverse("account:login_forbidden")}?{urlencode({"hint_msg": msg})}')
+
     def build_401_response(self, request):
 
         # 强制要求进行跳转的方式
@@ -90,9 +94,7 @@ class ResponseHandler(object):
         if hasattr(settings, "BLUEAPPS_PAGE_401_RESPONSE_FUNC"):
             return settings.BLUEAPPS_PAGE_401_RESPONSE_FUNC(request)
         _next = request.build_absolute_uri()
-        if request.method == "GET" and hasattr(
-            settings, "BLUEAPPS_SPECIFIC_REDIRECT_KEY"
-        ):
+        if request.method == "GET" and hasattr(settings, "BLUEAPPS_SPECIFIC_REDIRECT_KEY"):
             _next = request.GET.get(settings.BLUEAPPS_SPECIFIC_REDIRECT_KEY) or _next
         _redirect = build_redirect_url(
             _next,
@@ -109,9 +111,7 @@ class ResponseHandler(object):
         if hasattr(settings, "BLUEAPPS_PAGE_401_RESPONSE_PLATFORM_FUNC"):
             return settings.BLUEAPPS_PAGE_401_RESPONSE_PLATFORM_FUNC(request)
         _next = request.build_absolute_uri()
-        if request.method == "GET" and hasattr(
-            settings, "BLUEAPPS_SPECIFIC_REDIRECT_KEY"
-        ):
+        if request.method == "GET" and hasattr(settings, "BLUEAPPS_SPECIFIC_REDIRECT_KEY"):
             _next = request.GET.get(settings.BLUEAPPS_SPECIFIC_REDIRECT_KEY) or _next
         if self._conf.ADD_CROSS_PREFIX:
             _next = self._conf.CROSS_PREFIX + _next
@@ -127,9 +127,7 @@ class ResponseHandler(object):
     def _build_extra_args(self):
         extra_args = None
         if self._conf.ADD_APP_CODE:
-            extra_args = {
-                self._conf.APP_KEY: getattr(self._settings, self._conf.SETTINGS_APP_KEY)
-            }
+            extra_args = {self._conf.APP_KEY: getattr(self._settings, self._conf.SETTINGS_APP_KEY)}
         return extra_args
 
     def build_weixin_401_response(self, request):
@@ -138,9 +136,7 @@ class ResponseHandler(object):
         """
         _login_url = self._conf.WEIXIN_OAUTH_URL
         _next = request.build_absolute_uri()
-        if request.method == "GET" and hasattr(
-            settings, "BLUEAPPS_SPECIFIC_REDIRECT_KEY"
-        ):
+        if request.method == "GET" and hasattr(settings, "BLUEAPPS_SPECIFIC_REDIRECT_KEY"):
             _next = request.GET.get(settings.BLUEAPPS_SPECIFIC_REDIRECT_KEY) or _next
 
         extra_args = {
@@ -149,16 +145,14 @@ class ResponseHandler(object):
             "scope": "snsapi_base",
             "state": request.session["WEIXIN_OAUTH_STATE"],
         }
-        _redirect = build_redirect_url(
-            _next, _login_url, "redirect_uri", extra_args=extra_args
-        )
+        _redirect = build_redirect_url(_next, _login_url, "redirect_uri", extra_args=extra_args)
         return HttpResponseRedirect(_redirect)
 
     def build_rio_401_response(self, request):
         context = {
             "result": False,
             "code": RioVerifyError.ERROR_CODE,
-            "message": _(u"您的登陆请求无法经智能网关正常检测，请与管理人员联系"),
+            "message": _("您的登陆请求无法经智能网关正常检测，请与管理人员联系"),
         }
         return JsonResponse(context, status=401)
 
@@ -169,6 +163,6 @@ class ResponseHandler(object):
         context = {
             "result": False,
             "code": BkJwtVerifyError.ERROR_CODE,
-            "message": _(u"您的登陆请求无法经BK JWT检测，请与管理人员联系"),
+            "message": _("您的登陆请求无法经BK JWT检测，请与管理人员联系"),
         }
         return JsonResponse(context, status=401)
