@@ -20,7 +20,6 @@ from opentelemetry import trace
 from opentelemetry.sdk.trace import TracerProvider
 from opentelemetry.sdk.resources import Resource, SERVICE_NAME
 from opentelemetry.sdk.trace.sampling import _KNOWN_SAMPLERS
-from opentelemetry.sdk.trace.export import BatchSpanProcessor
 from opentelemetry.exporter.jaeger.thrift import JaegerExporter
 from opentelemetry.exporter.otlp.proto.grpc.trace_exporter import OTLPSpanExporter
 
@@ -30,11 +29,13 @@ from blueapps.opentelemetry.metrics.celery import MetricsServerStep
 from blueapps.opentelemetry.metrics.instrumentor import SaaSMetricsInstrumentor
 from blueapps.opentelemetry.constants import DEFAULT_LOGGING_TRACE_FORMAT
 from blueapps.opentelemetry.utils import inject_logging_trace_info
+from blueapps.opentelemetry.export import LazyBatchSpanProcessor
 
 
 def setup_trace_config(
     service_name: str, bk_data_id: int, otel_sampler: str, otel_grpc_host: str, bk_data_token: str = "",
 ):
+    span_processor = getattr(settings, "BLUEAPPS_BKAPP_OTEL_SPAN_PROCESSOR", LazyBatchSpanProcessor)
     if settings.ENVIRONMENT == "dev":
         # local environment, use jaeger as trace service
         # docker run -p 16686:16686 -p 6831:6831/udp jaegertracing/all-in-one
@@ -42,7 +43,7 @@ def setup_trace_config(
         jaeger_exporter = JaegerExporter(
             agent_host_name="localhost", agent_port=6831, udp_split_oversized_batches=True,
         )
-        trace.get_tracer_provider().add_span_processor(BatchSpanProcessor(jaeger_exporter))
+        trace.get_tracer_provider().add_span_processor(span_processor(jaeger_exporter))
     else:
         # stage and prod environment, use bk_log as trace service
         trace.set_tracer_provider(
@@ -54,7 +55,7 @@ def setup_trace_config(
             )
         )
         otlp_exporter = OTLPSpanExporter(endpoint=otel_grpc_host)
-        span_processor = BatchSpanProcessor(otlp_exporter)
+        span_processor = span_processor(otlp_exporter)
         trace.get_tracer_provider().add_span_processor(span_processor)
 
 
