@@ -11,7 +11,10 @@ an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express o
 specific language governing permissions and limitations under the License.
 """
 
-import collections
+try:
+    from collections import Callable
+except ImportError:
+    from collections.abc import Callable
 
 from django.contrib.auth import get_user_model
 from django.utils.module_loading import import_string
@@ -99,7 +102,7 @@ class SDKClient(object):
             ret = SDKClient(**self.common_args)
             ret.mod_name = item
             ret.setup_modules()
-            if isinstance(ret.sdk_mod, collections.Callable):
+            if isinstance(ret.sdk_mod, Callable):
                 return ret.sdk_mod
             return ret
         else:
@@ -107,7 +110,7 @@ class SDKClient(object):
             ret = getattr(self.sdk_mod, item, None)
             if ret is None:
                 ret = ComponentAPICollection(self).add_api(item)
-        if not isinstance(ret, collections.Callable):
+        if not isinstance(ret, Callable):
             ret = self
         return ret
 
@@ -126,14 +129,10 @@ class SDKClient(object):
             if settings.RUN_MODE != "DEVELOP":
                 if self.common_args:
                     return self.load_sdk_class("client", "ComponentClient")(
-                        app_code=settings.APP_CODE,
-                        app_secret=settings.SECRET_KEY,
-                        common_args=self.common_args,
+                        app_code=settings.APP_CODE, app_secret=settings.SECRET_KEY, common_args=self.common_args,
                     )
                 else:
-                    raise AccessForbidden(
-                        "sdk can only be called through the Web request"
-                    )
+                    raise AccessForbidden("sdk can only be called through the Web request")
             else:
                 # develop mode
                 # 根据RUN_VER获得get_component_client_common_args函数
@@ -173,9 +172,7 @@ class ComponentAPICollection(object):
 
     def __new__(cls, sdk_client, *args, **kwargs):
         if sdk_client.mod_name not in cls.mod_map:
-            cls.mod_map[sdk_client.mod_name] = super(
-                ComponentAPICollection, cls
-            ).__new__(cls)
+            cls.mod_map[sdk_client.mod_name] = super(ComponentAPICollection, cls).__new__(cls)
         return cls.mod_map[sdk_client.mod_name]
 
     def __init__(self, sdk_client):
@@ -207,17 +204,13 @@ class CustomComponentAPI(object):
             client=SDKClient(**self.collection.client.common_args),
             method=method,
             path="{api_prefix}{collection}/{action}/".format(
-                api_prefix=ESB_API_PREFIX,
-                collection=self.collection.client.mod_name,
-                action=self.action,
+                api_prefix=ESB_API_PREFIX, collection=self.collection.client.mod_name, action=self.action,
             ),
             description="custom api(%s)" % self.action,
         )
 
     def __call__(self, *args, **kwargs):
-        raise NotImplementedError(
-            "custom api `%s` must specify the request method" % self.action
-        )
+        raise NotImplementedError("custom api `%s` must specify the request method" % self.action)
 
 
 try:
@@ -237,9 +230,7 @@ def get_client_by_user(user_or_username):
         username = user_or_username.username
     else:
         username = user_or_username
-    get_client_by_user = import_string(
-        ".".join([ESB_SDK_NAME, "shortcuts", "get_client_by_user"])
-    )
+    get_client_by_user = import_string(".".join([ESB_SDK_NAME, "shortcuts", "get_client_by_user"]))
     return get_client_by_user(username)
 
 
